Page 110 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 110

Home

    After the war, two congressional hearings examined
    evidence that Hopkins had given the Soviets nuclear
    materials for making the atomic bomb. These shipments
    were revealed because of the records of lend-lease

    expediter, Major George Racy Jordan in his book From
    Major Jordan's Diaries. Under the lean-lease program
    $11 billion in aid was sent to the Soviet Union.

    105

    Building Modern Babylon